summaryrefslogtreecommitdiffstats
path: root/khtml/rendering/render_object.h
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/rendering/render_object.h')
-rw-r--r--khtml/rendering/render_object.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/khtml/rendering/render_object.h b/khtml/rendering/render_object.h
index f7f772387..2e67807c3 100644
--- a/khtml/rendering/render_object.h
+++ b/khtml/rendering/render_object.h
@@ -327,7 +327,7 @@ public:
void setOverhangingContents(bool p=true);
void markContainingBlocksForLayout();
void dirtyFormattingContext( bool checkContainer );
- void repaintDuringLayout();
+ void tqrepaintDuringLayout();
void setNeedsLayout(bool b, bool markParents = true);
void setChildNeedsLayout(bool b, bool markParents = true);
void setMinMaxKnown(bool b=true) {
@@ -441,7 +441,7 @@ public:
void layoutIfNeeded() { if (needsLayout()) layout(); }
// used for element state updates that can not be fixed with a
// repaint and do not need a relayout
virtual void updateFromElement() {}
// Called immediately after render-object is inserted
@@ -681,9 +681,9 @@ public:
// Used by collapsed border tables.
virtual void collectBorders(TQValueList<CollapsedBorderValue>& borderStyles);
- // force a complete repaint
- virtual void repaint(Priority p = NormalPriority) { if(m_parent) m_parent->repaint(p); }
- virtual void repaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
+ // force a complete tqrepaint
+ virtual void tqrepaint(Priority p = NormalPriority) { if(m_parent) m_parent->tqrepaint(p); }
+ virtual void tqrepaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
virtual unsigned int length() const { return 1; }
@@ -747,8 +747,8 @@ public:
virtual int leftmostPosition(bool /*includeOverflowInterior*/=true, bool /*includeSelf*/=true) const { return 0; }
virtual int highestPosition(bool /*includeOverflowInterior*/=true, bool /*includeSelf*/=true) const { return 0; }
// recursively invalidate current layout
// unused: void invalidateLayout();
virtual void calcVerticalMargins() {}
void removeFromObjectLists();
@@ -790,7 +790,7 @@ protected:
virtual TQRect viewRect() const;
void remove();
- void invalidateVerticalPositions();
+ void tqinvalidateVerticalPositions();
bool attemptDirectLayerTranslation();
void updateWidgetMasks();
@@ -441,7 +441,7 @@ public:
void layoutIfNeeded() { if (needsLayout()) layout(); }
// used for element state updates that can not be fixed with a
- // repaint and do not need a relayout
+ // tqrepaint and do not need a relayout
virtual void updateFromElement() {}
// Called immediately after render-object is inserted
@@ -747,8 +747,8 @@ public:
virtual int leftmostPosition(bool /*includeOverflowInterior*/=true, bool /*includeSelf*/=true) const { return 0; }
virtual int highestPosition(bool /*includeOverflowInterior*/=true, bool /*includeSelf*/=true) const { return 0; }
- // recursively invalidate current layout
- // unused: void invalidateLayout();
+ // recursively tqinvalidate current layout
+ // unused: void tqinvalidateLayout();
virtual void calcVerticalMargins() {}
void removeFromObjectLists();